==> lxqt-panel-0.15.1.tar.xz: lxqt-panel-0.15.1/plugin-taskbar/translations/taskbar_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../lxqttaskbar.cpp" line="655"/>
        <source>Activate task %1</source>
        <translation>Aktivovat úlohu %1</translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="635"/>
        <source>Application</source>
        <translation>Aplikace</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="669"/>
        <source>To &amp;Desktop</source>
        <translation>Na &amp;plochu</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="671"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Všechny plochy</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="679"/>
        <source>Desktop &amp;%1</source>
        <translation>Plocha &amp;%1</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="686"/>
        <source>&amp;To Current Desktop</source>
        <translation>Na s&amp;távající plochu</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="694"/>
        <source>&amp;Move</source>
        <translation>&amp;Přesunout</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="697"/>
        <source>Resi&amp;ze</source>
        <translation>&amp;Změnit velikost</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="704"/>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ximalizovat</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="711"/>
        <source>Maximize vertically</source>
        <translation>Maximalizovat ve svislém směru</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="716"/>
        <source>Maximize horizontally</source>
        <translation>Maximalizovat ve vodorovném směru</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="722"/>
        <source>&amp;Restore</source>
        <translation>&amp;Obnovit předchozí velikost</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="726"/>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimalizovat</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="732"/>
        <source>Roll down</source>
        <translation>Sbalit</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="738"/>
        <source>Roll up</source>
        <translation>Rozbalit</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="746"/>
        <source>&amp;Layer</source>
        <translation>&amp;Vrstva</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="748"/>
        <source>Always on &amp;top</source>
        <translation>Vždy &amp;navrchu</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="754"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normální</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="760"/>
        <source>Always on &amp;bottom</source>
        <translation>Vždy &amp;naspodu</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="768"/>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="82"/>
        <source>Group</source>
        <translation>Seskupit</translation>
    </message>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="84"/>
        <source>Close group</source>
        <translation>Zavřít skupinu</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>Nastavení Správce úloh</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>Ukazovat pouze okna z dané plochy</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>Ukazovat pouze okna z obrazovky, na které se daný &amp;panel nachází</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>Ukazovat pouze minimalizovaná okna</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>Vyzdvihnout minimalizovaná okna stávající plochy</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="49"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation>Přepínat mezi okny otáčením kolečka myši</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="143"/>
        <source>Window &amp;grouping</source>
        <translation>&amp;Seskupování oken</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="152"/>
        <source>Show popup on mouse hover</source>
        <translation>Při najetí ukazatelem myši zobrazit vyskakovací okno</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="162"/>
        <source>Appearance</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="181"/>
        <source>Maximum button width</source>
        <translation>Šířka tlačítka maximálně</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="125"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="194"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="220"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="86"/>
        <source>Mouse Wheel</source>
        <translation>Kolečko myši</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Wheel Delta Threshold</source>
        <translation>Práh přírůstku pootočení kolečka</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="207"/>
        <source>Maximum button height</source>
        <translation>Výška tlačítka maximálně</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="240"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>Použít ikony podle třídy okna (pokud je k dispozici)</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="233"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>Při svisle o&amp;rientovaném panelu otočit tlačítka tak, aby byla vodorovně</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="171"/>
        <source>Button style</source>
        <translation>Styl tlačítek</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>Zavírat kliknutím prostředním tlačítkem</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="44"/>
        <source>Icon and text</source>
        <translation>Ikona a text</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="45"/>
        <source>Only icon</source>
        <translation>Pouze ikona</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Only text</source>
        <translation>Pouze text</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="48"/>
        <source>Disabled</source>
        <translation>Vypnuto</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="50"/>
        <source>Scroll up to raise, down to minimize</source>
        <translation>Otáčením nahoru přenést do popředí, dolů minimalizovat</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="51"/>
        <source>Scroll up to minimize, down to raise</source>
        <translation>Otáčením nahoru minimalizovat, dolů přenést do popředí</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="52"/>
        <source>Scroll up to move to next desktop, down to previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="53"/>
        <source>Scroll up to move to previous desktop, down to next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="55"/>
        <source>Current</source>
        <translation>Stávající</translation>
    </message>
</context>
</TS>

==> lxqt-panel_0.16.1.orig.tar.xz: lxqt-panel-0.16.1/plugin-taskbar/translations/taskbar_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../lxqttaskbar.cpp" line="681"/>
        <source>Activate task %1</source>
        <translation>Aktivovat úlohu %1</translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="679"/>
        <source>Application</source>
        <translation>Aplikace</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="713"/>
        <source>To &amp;Desktop</source>
        <translation>Na &amp;plochu</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="715"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Všechny plochy</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="723"/>
        <source>Desktop &amp;%1</source>
        <translation>Plocha &amp;%1</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="730"/>
        <source>&amp;To Current Desktop</source>
        <translation>Na s&amp;távající plochu</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="739"/>
        <source>Move To &amp;Next Monitor</source>
        <translation>Přesunout na &amp;další obrazovku</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="742"/>
        <source>Move To &amp;Previous Monitor</source>
        <translation>Přesunout na &amp;předchozí obrazovku</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="746"/>
        <source>&amp;Move</source>
        <translation>&amp;Přesunout</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="749"/>
        <source>Resi&amp;ze</source>
        <translation>&amp;Změnit velikost</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="756"/>
        <source>Ma&amp;ximize</source>
        <translation>Z&amp;většit</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="763"/>
        <source>Maximize vertically</source>
        <translation>Udělat největším ve svislém směru</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="768"/>
        <source>Maximize horizontally</source>
        <translation>Udělat největším ve vodorovném směru</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="774"/>
        <source>&amp;Restore</source>
        <translation>&amp;Obnovit předchozí velikost</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="778"/>
        <source>Mi&amp;nimize</source>
        <translation>&amp;Zmenšit</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="784"/>
        <source>Roll down</source>
        <translation>Sbalit</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="790"/>
        <source>Roll up</source>
        <translation>Rozbalit</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="798"/>
        <source>&amp;Layer</source>
        <translation>&amp;Vrstva</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="800"/>
        <source>Always on &amp;top</source>
        <translation>Vždy &amp;navrchu</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="806"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normální</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="812"/>
        <source>Always on &amp;bottom</source>
        <translation>Vždy &amp;naspodu</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="820"/>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="82"/>
        <source>Group</source>
        <translation>Seskupit</translation>
    </message>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="84"/>
        <source>Close group</source>
        <translation>Zavřít skupinu</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>Nastavení Správce úloh</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>Ukazovat pouze okna z dané plochy</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>Ukazovat pouze okna z obrazovky, na které se daný &amp;panel nachází</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>Ukazovat pouze minimalizovaná okna</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>Vyzdvihnout minimalizovaná okna stávající plochy</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="49"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation>Přepínat mezi okny otáčením kolečka myši</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="143"/>
        <source>Window &amp;grouping</source>
        <translation>&amp;Seskupování oken</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="152"/>
        <source>Show popup on mouse hover</source>
        <translation>Při najetí ukazatelem myši zobrazit vyskakovací okno</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="169"/>
        <source>Appearance</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="188"/>
        <source>Maximum button width</source>
        <translation>Šířka tlačítka maximálně</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="125"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="201"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="227"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="86"/>
        <source>Mouse Wheel</source>
        <translation>Kolečko myši</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Wheel Delta Threshold</source>
        <translation>Práh přírůstku pootočení kolečka</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="162"/>
        <source>Put buttons of the same class next to each other</source>
        <translation>Dát tlačítka stejné třídy vedle sebe</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="214"/>
        <source>Maximum button height</source>
        <translation>Výška tlačítka maximálně</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="247"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>Použít ikony podle třídy okna (pokud je k dispozici)</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="240"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>Při svisle o&amp;rientovaném panelu otočit tlačítka tak, aby byla vodorovně</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="178"/>
        <source>Button style</source>
        <translation>Styl tlačítek</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>Zavírat kliknutím prostředním tlačítkem</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="44"/>
        <source>Icon and text</source>
        <translation>Ikona a text</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="45"/>
        <source>Only icon</source>
        <translation>Pouze ikona</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Only text</source>
        <translation>Pouze text</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="48"/>
        <source>Disabled</source>
        <translation>Vypnuto</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="50"/>
        <source>Scroll up to raise, down to minimize</source>
        <translation>Otáčením nahoru přenést do popředí, dolů minimalizovat</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="51"/>
        <source>Scroll up to minimize, down to raise</source>
        <translation>Otáčením nahoru minimalizovat, dolů přenést do popředí</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="52"/>
        <source>Scroll up to move to next desktop, down to previous</source>
        <translation>Posunout nahoru pro přesun na další plochu, dolů pro přesun na předchozí</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="53"/>
        <source>Scroll up to move to previous desktop, down to next</source>
        <translation>Posunout nahoru pro přesun na předchozí plochu, dolů pro přesun na další</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="55"/>
        <source>Current</source>
        <translation>Stávající</translation>
    </message>
</context>
</TS>
